# PDFlib PLOP DS:
# Demonstrate digital signature features with optional signature visualization

from sys import *
from PDFlib.PLOP import *

# Basic signature options 

# use ltv=full to ensure LTV status
# for  use with PKCS11
# "engine=pkcs#11 digitalid={filename=cryptoki.dll} "
sign_opts = \
    "ltv=try " \
    "engine=builtin digitalid={filename=demo_signer_rsa_2048.p12} password={demo} "
    

# This is where input files live. Adjust as necessary.
searchpath = "../data"

# Set to 1 to enable signature visualization 
visualize = 1
visfile = "signing_man_pdfa1a.pdf"

if len(argv) != 3 :
    raise Exception("usage: sign <infile> <outfile>" )

plop = None
try:
    # create a new PLOP object
    plop = PLOP()

    optlist = "searchpath={%s}" % searchpath
    plop.set_option(optlist)

    doc = plop.open_document(argv[1], "")
    if (doc == -1):
        raise Exception("Error: %s: %s" % (plop.get_apiname(),
                                                 plop.get_errmsg()))

    optlist = sign_opts;        

    if (visualize):
        visdoc = plop.open_document(visfile, "")
        if (visdoc == -1):
            raise Exception("Error: %s: %s" % (plop.get_apiname(),
                                                     plop.get_errmsg()))
        optlist += "field={visdoc=%d rect={50 50 adapt adapt}} " % visdoc

    if (plop.prepare_signature(optlist) == -1):
        raise Exception("Error: %s: %s" % (plop.get_apiname(),
                                                 plop.get_errmsg()))

    optlist = "input={%d}" % doc
    if (plop.create_document(argv[2], optlist) == -1):
        raise Exception("Error: %s: %s" % (plop.get_apiname(),
                                                 plop.get_errmsg()))

    plop.close_document(doc, "")
    if (visualize):
        plop.close_document(visdoc, "")

except PLOPException as ex:
    print("PDFlib PLOP exception occurred:")
    print("[%d] %s: %s" % (ex.errnum, ex.apiname, ex.errmsg))

except Exception as ex:
    print(ex)

finally:
    if plop:
        plop.delete()
